# CHANGELOG


## v0.1.0 (2026-05-06)

### Features

- Add common tracing module for honeycomb
  ([`7e09974`](https://github.com/20206205Tech/20206205tech-python-common/commit/7e099742ffc9902eb6fd1a5e001aa52d854facdb))


## v0.0.0 (2026-05-06)
